.. image:: https://img.shields.io/pypi/v/aeroframe.svg?style=flat
   :target: https://pypi.org/project/aeroframe/
   :alt: Latest PyPI version

.. image:: https://readthedocs.org/projects/aeroframe/badge/?version=latest
    :target: https://aeroframe.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://img.shields.io/badge/license-Apache%202-blue.svg
    :target: https://github.com/airinnova/aeroframe/blob/master/LICENSE.txt
    :alt: License

.. image:: https://travis-ci.org/airinnova/aeroframe.svg?branch=master
    :target: https://travis-ci.org/airinnova/aeroframe
    :alt: Build status

.. image:: https://codecov.io/gh/airinnova/aeroframe/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/airinnova/aeroframe
    :alt: Coverage

|

.. image:: https://raw.githubusercontent.com/airinnova/aeroframe/master/docs/source/_static/images/logo/logo.png
    :alt: Logo
    :width: 200 px
    :scale: 100 %

*AeroFrame* (*Aeroelastic Framework*) is a modular framework for partitioned aeroelastic analyses. The framework couples separate solvers for structure and CFD. It coordinates the analysis and the exchange of loads and deformations. Currently, AeroFrame supports *static*  aeroelastic analyses.

.. image:: https://raw.githubusercontent.com/airinnova/aeroframe/master/docs/source/_static/images/cover_img_small.png
    :alt: Logo
    :width: 300 px
    :scale: 100 %

Documentation
-------------

* https://aeroframe.readthedocs.io/

License
-------

**License:** Apache-2.0
